@@ -11,6 +11,7 @@ from tornado.ioloop import IOLoop
 
 from .progress import format_time, Progress, MultiProgress
 
+from ..compatibility import html_escape
 from ..core import connect, coerce_to_address, CommClosedError
 from ..client import default_client, futures_of
 from ..protocol.pickle import dumps
@@ -227,13 +228,12 @@ class MultiProgressWidget(MultiProgressBar):
 
     def make_widget(self, all):
         from ipywidgets import FloatProgress, HBox, VBox, HTML
-        import cgi
         self.elapsed_time = HTML('')
         self.bars = {key: FloatProgress(min=0, max=1, description='',
                                         height='10px')
                         for key in all}
         self.bar_texts = {key: HTML('', width = "140px") for key in all}
-        self.bar_labels = {key: HTML('<div style=\"padding: 0px 10px 0px 10px; text-align:left; word-wrap: break-word;\">' + cgi.escape(key.decode() if isinstance(key, bytes) else key) + '</div>')
+        self.bar_labels = {key: HTML('<div style=\"padding: 0px 10px 0px 10px; text-align:left; word-wrap: break-word;\">' + html_escape(key.decode() if isinstance(key, bytes) else key) + '</div>')
                             for key in all}
 
         def key(kv):
