@@ -163,19 +163,32 @@ def test_dataframe_groupby_tasks(loop):
             with dask.set_options(get=c.get):
                 for ind in [lambda x: 'A', lambda x: x.A]:
                     a = df.groupby(ind(df)).apply(len)
-                    b = ddf.groupby(ind(ddf)).apply(len)
+                    b = ddf.groupby(ind(ddf)).apply(len, meta=int)
                     assert_equal(a, b.compute(get=dask.get).sort_index())
                     assert not any('partd' in k[0] for k in b.dask)
 
                     a = df.groupby(ind(df)).B.apply(len)
-                    b = ddf.groupby(ind(ddf)).B.apply(len)
+                    b = ddf.groupby(ind(ddf)).B.apply(len, meta=('B', int))
                     assert_equal(a, b.compute(get=dask.get).sort_index())
                     assert not any('partd' in k[0] for k in b.dask)
 
                 with pytest.raises(NotImplementedError):
-                    ddf.groupby(ddf[['A', 'B']]).apply(len)
+                    ddf.groupby(ddf[['A', 'B']]).apply(len, meta=int)
 
                 a = df.groupby(['A', 'B']).apply(len)
-                b = ddf.groupby(['A', 'B']).apply(len)
+                b = ddf.groupby(['A', 'B']).apply(len, meta=int)
 
                 assert_equal(a, b.compute(get=dask.get).sort_index())
+
+
+@gen_cluster(client=True)
+def test_sparse_arrays(c, s, a, b):
+    sparse = pytest.importorskip('sparse')
+    da = pytest.importorskip('dask.array')
+
+    x = da.random.random((100, 10), chunks=(10, 10))
+    x[x < 0.95] = 0
+    s = x.map_blocks(sparse.COO)
+    future = c.compute(s.sum(axis=0)[:10])
+
+    yield future
