@@ -274,6 +274,7 @@ def test_server_listens_to_other_ops(s, a, b):
     with rpc(s.address) as r:
         ident = yield r.identity()
         assert ident['type'] == 'Scheduler'
+        assert ident['id'].lower().startswith('scheduler')
 
 
 @gen_cluster()
@@ -737,8 +738,7 @@ def test_launch_without_blocked_services():
 @gen_cluster(ncores=[], client=True)
 def test_scatter_no_workers(c, s):
     with pytest.raises(gen.TimeoutError):
-        yield gen.with_timeout(timedelta(seconds=0.1),
-                               s.scatter(data={'x': 1}, client='alice'))
+        yield s.scatter(data={'x': 1}, client='alice', timeout=0.1)
 
     w = Worker(s.ip, s.port, ncores=3)
     yield [c._scatter(data={'x': 1}),
